@@ -91,6 +91,14 @@ void defaults()
 	safecopy(state.ampmcolor, "#a0a0a0", MAX_OPT_LEN);
 	safecopy(state.datecolor, "#a0a0a0", MAX_OPT_LEN);
 
+	/* label options */
+	state.show_label = 0;
+	state.label_top = 0;
+	safecopy(state.label, "astime", 256);
+	safecopy(state.font_name, 
+			"-*-helvetica-medium-r-*-*-9-240-*-*-*-*-*-*", 256);
+	safecopy(state.label_color, "#a0a0a0", MAX_OPT_LEN);
+
 	/* clear hand rendering options */
 	for (i = 0; i < 3; i++) {
 		for (j = 0; j < 3; j++)
@@ -144,6 +152,10 @@ void usage()
 	printf("-ht <0-200>      hand thickness\n");
 	printf("-ot <0-200>      hand outline thickness (with -fh)\n");
 	printf("-nf              no foreground (-nd -nap -nt)\n");
+	printf("-label <text>    show the label <text> on the clock\n");
+	printf("-fn <name>       use the font name for the label\n");
+	printf("-lcol <color>    color to use for the label\n");
+	printf("-ltop            the label should go on top\n");
 	printf("\n");
 	exit(0);
 }
@@ -151,7 +163,7 @@ void usage()
 /* print the version of the tool */
 void version()
 {
-	printf("astime : AfterStep analog clock version 2.2\n");
+	printf("astime : AfterStep analog clock version 2.3\n");
 }
 
 /* parse the rc file */
@@ -233,6 +245,19 @@ void parsercfile(FILE * ifp)
 				safecopy(state.ampmcolor, param[1], MAX_OPT_LEN);
 			} else if (!strcmp(param[0], "dateColor")) {
 				safecopy(state.datecolor, param[1], MAX_OPT_LEN);
+			} else if (!strcmp(param[0], "Label")) {
+				state.show_label = 1;
+				safecopy(state.label, param[1], 256);
+			} else if (!strcmp(param[0], "Font")) {
+				safecopy(state.font_name, param[1], 256);
+			} else if (!strcmp(param[0], "LabelColor")) {
+				safecopy(state.label_color, param[1], MAX_OPT_LEN);
+			} else if (!strcmp(param[0], "LabelTop")) {
+				tval = atoi(param[1]);
+				if (tval == 0)
+					state.label_top = 0;
+				else
+					state.label_top = 1;
 			} else if (!strcmp(param[0], "drawSecondHand")) {
 				tval = atoi(param[1]);
 				if (tval)
@@ -418,6 +443,21 @@ void parsecmdline(int argc, char *argv[])
 				if (++i >= argc)
 					usage();
 				safecopy(state.fgcolor, argv[i], MAX_OPT_LEN);
+			} else if (!strncmp(argument, "-label", 6)) {
+				if (++i >= argc)
+					usage();
+				state.show_label = 1;
+				safecopy(state.label, argv[i], 256);
+			} else if (!strncmp(argument, "-fn", 3)) {
+				if (++i >= argc)
+					usage();
+				safecopy(state.font_name, argv[i], 256);
+			} else if (!strncmp(argument, "-lcolor", 3)) {
+				if (++i >= argc)
+					usage();
+				safecopy(state.label_color, argv[i], MAX_OPT_LEN);
+			} else if (!strncmp(argument, "-ltop", 4)) {
+				state.label_top = 1;
 			} else if (!strncmp(argument, "-sec", 4)) {
 				if (++i >= argc)
 					usage();
