@@ -50,6 +50,12 @@ XGCValues mainGCV;		/* graphics context values */
 GC mainGC;			/* Graphics context */
 Atom wm_delete_window;
 Atom wm_protocols;
+Font label_font;
+XFontStruct * label_fnstruct;
+
+/* the label position and color */
+int label_x, label_y;
+Pixel label_pix;
 
 /* background, digits, months etc pixmap colors */
 char bgpixmap_color[4][32];
@@ -304,6 +310,24 @@ void draw_window(Window win)
 		}
 	}
 
+	if ( state.show_label ) {
+		mainGCV.foreground = label_pix;
+		XChangeGC(
+				 mainDisplay,
+				 mainGC,
+				 GCForeground,
+				 &mainGCV
+		    );
+		XDrawString(
+				mainDisplay,
+				win,
+				mainGC,
+				label_x,
+				label_y,
+				state.label,
+				strlen(state.label)
+				);
+	}
 }
 
 /* convert the position on 0-60 scale into xy coordinates */
@@ -617,6 +641,48 @@ void initialize(int argc, char **argv,
 	int y_negative = 0;
 	int x_size_forced = 0;
 	int y_size_forced = 0;
+	int label_w = 0;
+	int label_h = 0;
+
+	mainDisplay = XOpenDisplay(display_name);
+	if (!mainDisplay) {
+		printf("astime : grrrr... can't open display %s. Sorry ...\n",
+		       XDisplayName(display_name));
+		exit(1);
+	}
+	screen = DefaultScreen(mainDisplay);
+	Root = RootWindow(mainDisplay, screen);
+	back_pix = GetColor(state.bgcolor, mainDisplay, Root);
+	fore_pix = GetColor(state.fgcolor, mainDisplay, Root);
+	color_depth = DefaultDepth(mainDisplay, screen);
+#ifdef DEBUG
+	printf("astime : detected color depth %d bpp, using %d bpp\n",
+	       color_depth, color_depth);
+#endif
+	/* Set up the font for the label */
+	if ( state.show_label ) {
+		label_fnstruct = XLoadQueryFont( mainDisplay, state.font_name );
+		if ( ! label_fnstruct ) {
+			printf("astime : failed to load font %s\n",
+					state.font_name);
+			printf("astime : warning : the label will not be drawn\n");
+			state.show_label = 0;
+		} else {
+			label_font = label_fnstruct->fid;
+			label_w = XTextWidth(
+					label_fnstruct,
+					state.label,
+					strlen(state.label)
+					);
+			label_h = label_fnstruct->max_bounds.ascent +
+				label_fnstruct->max_bounds.descent;
+#ifdef DEBUG
+	printf("astime : loaded font %s\n", state.font_name);
+	printf("astime : label width is %d, height is %d [label \"%s\"]\n",
+			label_w, label_h, state.label);
+#endif
+		}
+	}
 
 	if (strlen(mainGeometry)) {
 		/* Check the user-specified size */
@@ -643,6 +709,7 @@ void initialize(int argc, char **argv,
 		       SizeHints.x, SizeHints.y, x_negative, y_negative);
 #endif
 	}
+	/* adjust the coordinate/size for the date */
 	if (state.draw_date) {
 		center.x = state.total_size.x / 2;
 		center.y = state.total_size.y / 2 - 4;
@@ -654,22 +721,23 @@ void initialize(int argc, char **argv,
 		watch_size.x = center.x - 3;
 		watch_size.y = center.y - 3;
 	}
-
-	mainDisplay = XOpenDisplay(display_name);
-	if (!mainDisplay) {
-		printf("astime : grrrr... can't open display %s. Sorry ...\n",
-		       XDisplayName(display_name));
-		exit(1);
+	/* adjust the coordinates/size for the label */
+	if ( state.show_label ) {
+		if ( state.label_top )
+			center.y += label_h/2 + 1;
+		else
+			center.y -= label_h/2;
+		watch_size.y -= label_h/2 + 1;
+		label_x = state.total_size.x / 2 - label_w / 2;
+		if ( state.label_top )
+			label_y = label_h;
+		else {
+			if ( state.draw_date )
+				label_y = state.total_size.y - 10;
+			else
+				label_y = state.total_size.y - 3;
+		}
 	}
-	screen = DefaultScreen(mainDisplay);
-	Root = RootWindow(mainDisplay, screen);
-	back_pix = GetColor(state.bgcolor, mainDisplay, Root);
-	fore_pix = GetColor(state.fgcolor, mainDisplay, Root);
-	color_depth = DefaultDepth(mainDisplay, screen);
-#ifdef DEBUG
-	printf("astime : detected color depth %d bpp, using %d bpp\n",
-	       color_depth, color_depth);
-#endif
 
 	/* The day-of-week pixmap */
 	sprintf(dof_pixmap_color[0], "c c %s", state.bgcolor);
@@ -886,12 +954,22 @@ void initialize(int argc, char **argv,
 	mainGCV.line_style = LineSolid;
 	mainGCV.fill_style = FillSolid;
 	mainGCV.line_width = 1;
-	mainGC = XCreateGC(mainDisplay,
-			   mainWindow,
-			   GCForeground | GCBackground | GCLineWidth |
-			   GCLineStyle | GCFillStyle,
-			   &mainGCV
-	    );
+	if ( state.show_label ) {
+		mainGCV.font = label_font;
+		mainGC = XCreateGC(mainDisplay,
+				   mainWindow,
+				   GCForeground | GCBackground | GCLineWidth |
+				   GCLineStyle | GCFillStyle | GCFont,
+				   &mainGCV
+		    );
+	} else {
+		mainGC = XCreateGC(mainDisplay,
+				   mainWindow,
+				   GCForeground | GCBackground | GCLineWidth |
+				   GCLineStyle | GCFillStyle,
+				   &mainGCV
+		    );
+	}
 
 	/* Draw the background */
 	mainGCV.foreground = back_pix;
@@ -1053,6 +1131,9 @@ void initialize(int argc, char **argv,
 	if (strcmp(state.hourfillcolor, "<>"))
 		pix[8] = GetColor(state.hourfillcolor, mainDisplay, Root);
 
+	/* Get the label color */
+	label_pix = GetColor(state.label_color, mainDisplay, Root);
+
 	/* try to read the time */
 	curTime = time(0);
 	last_time = curTime;
